start

# popuretext

Extracts all the source text from a directory of POT files, removing PO headers and optionally the accelerator keys.

If you want to use other tools to analyse the text within a translation project to for instance use word frequency to create an initial glossary then this tool is the starting point to get hold of the pure text.

## Prerequisites

GNU Gettext

## Usage

    popuretext <pot-dir> <file.txt> [accelerator]

Where:

pot-dir | a directory containing POT files
file.txt | file that contains the output text
accelerator | optional: accelerator marker to be removed from the text

## Bugs

None known